# Generated by Django 2.2.4 on 2019-08-16 17:10

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Permalinks',
            fields=[
                ('added_on', models.DateTimeField(auto_now_add=True, null=True)),
                ('updated_on', models.DateTimeField(auto_now_add=True, null=True)),
                ('permalink_id', models.BigAutoField(primary_key=True, serialize=False)),
                ('old_url', models.URLField(help_text='This is the URL that will be redirected.<br>Follow Full URL Scheme: <b>https://www.example.com/myapp/mypage.html</b>', max_length=300, verbose_name='Old URL')),
                ('new_url', models.URLField(help_text='This is the URL to which the above URL will be redirected.<br>Follow Full URL Scheme: <b>https://www.example.com/myapp/mypage.html</b>', max_length=300, verbose_name='New URL')),
            ],
            options={
                'verbose_name': 'Permalink',
                'verbose_name_plural': 'Permalinks',
            },
        ),
    ]
